window.Gleam.initSearch([{"doc":"apollo","title":"apollo","content":"# Apollo\n\n[![Package Version](https://img.shields.io/hexpm/v/apollo)](https://hex.pm/packages/apollo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/apollo/)\n\nA validation library named after the God of truth and prophecy.\n\n## An Basic Example\n\n```gleam\nimport gleam/io\nimport apollo/t\nimport apollo/filter as f\n\npub type Post {\n  Post(id: String, timestamp: Int, title: String, content: String)\n}\n\npub fn main() {\n  let post_schema: t.Schema(Post) =\n    apollo.typed(\n      Post,\n      [\n        #(\n          &quot;id&quot;,\n          t.string()\n          |&gt; f.min(4)\n          |&gt; f.max(10),\n        ),\n        #(\n          &quot;timestamp&quot;,\n          t.int()\n          |&gt; f.length(10),\n        ),\n        #(\n          &quot;title&quot;,\n          t.string()\n          |&gt; f.min(3)\n          |&gt; f.max(40),\n        ),\n        #(&quot;content&quot;, t.string()),\n      ],\n    )\n\n  let post =\n    apollo.validate(\n      post_schema,\n      #(\n        #(&quot;id&quot;, &quot;549&quot;),\n        // id should be at least 4 characters\n        #(&quot;timestamp&quot;, 1_691_611_376),\n        #(&quot;title&quot;, &quot;Apollo, the God of Truth and Prophecy&quot;),\n        #(\n          &quot;content&quot;,\n          &quot;Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.&quot;,\n        ),\n      ),\n    )\n  io.debug(post) // Error(&quot;Length of \\&quot;549\\&quot; is less than than 4&quot;)\n}\n```\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add apollo\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/apollo&gt;.\n","url":"index.html"},{"doc":"apollo/util","title":"AnyType","content":"pub type AnyType {\n  IntT(Int)\n  StringT(String)\n  FloatT(Float)\n  BoolT(Bool)\n}\n Used when making custon filters to check the type of a value\nIntT(Int)\n\n\nStringT(String)\n\n\nFloatT(Float)\n\n\nBoolT(Bool)\n\n\nSynonyms:\napollo/util.AnyType\napollo/util AnyType","url":"apollo/util.html#AnyType"},{"doc":"apollo/util","title":"to_err","content":"pub fn to_err(b: Bool, err: String) -&gt; Result(Nil, String)\n Shorthand for converting a Boolean to a Result\nSynonyms:\napollo/util.to_err\napollo/util to_err","url":"apollo/util.html#to_err"},{"doc":"apollo/util","title":"apollo/util","content":"","url":"apollo/util.html"},{"doc":"apollo/t","title":"Schema","content":"pub type Schema(t)\n\n\nSynonyms:\napollo/t.Schema\napollo/t Schema","url":"apollo/t.html#Schema"},{"doc":"apollo/t","title":"Value","content":"pub type Value\n\n\nSynonyms:\napollo/t.Value\napollo/t Value","url":"apollo/t.html#Value"},{"doc":"apollo/t","title":"bool","content":"pub fn bool() -&gt; Value\n\nSynonyms:\napollo/t.bool\napollo/t bool","url":"apollo/t.html#bool"},{"doc":"apollo/t","title":"float","content":"pub fn float() -&gt; Value\n\nSynonyms:\napollo/t.float\napollo/t float","url":"apollo/t.html#float"},{"doc":"apollo/t","title":"int","content":"pub fn int() -&gt; Value\n\nSynonyms:\napollo/t.int\napollo/t int","url":"apollo/t.html#int"},{"doc":"apollo/t","title":"string","content":"pub fn string() -&gt; Value\n\nSynonyms:\napollo/t.string\napollo/t string","url":"apollo/t.html#string"},{"doc":"apollo/t","title":"apollo/t","content":"","url":"apollo/t.html"},{"doc":"apollo","title":"typed","content":"pub fn typed(type_: a, schema: List(#(String, Value))) -&gt; Schema(\n  b,\n)\n Returns a schema to be used by `validate`. Takes in a type constructor and a list of key, value pairs.\n # Example\n     type Id {\n       Id(id: String)\n     }\n     let res: t.Schema(Id) = typed(\n         Id, \n         #(\n             #(&quot;id&quot;, t.string())\n         )\n     )\nSynonyms:\napollo.typed\napollo typed","url":"apollo.html#typed"},{"doc":"apollo","title":"validate","content":"pub fn validate(schema: Schema(a), obj: b) -&gt; Result(a, String)\n Takes in a schema from `typed` along with a mapping and returns a result of the type.\n # Example\n     let res: t.Schema(Id) = typed(...)\n     let assert Ok(my_id) = validate(res, [#(&quot;id&quot;, &quot;1532594324&quot;)])\n     // type of `my_id` is `Id`\nSynonyms:\napollo.validate\napollo validate","url":"apollo.html#validate"},{"doc":"apollo","title":"apollo","content":"","url":"apollo.html"},{"doc":"apollo/filter","title":"custom","content":"pub fn custom(v: Value, validator: fn(AnyType) -&gt;\n    Result(Nil, String)) -&gt; Value\n Create a custom filter\n # Example\n     pub fn is_gleam(v: Value) {\n         custom(\n           v,\n           fn(value: AnyType) {\n             case value {\n               StringT(t) -&gt; to_err(t == &quot;Gleam&quot;, &quot;Uh oh, expecting the word Gleam&quot;)\n               _ -&gt; Error(&quot;Type mismatch, expecting String&quot;)\n             }\n           }\n         )\n      }\nSynonyms:\napollo/filter.custom\napollo/filter custom","url":"apollo/filter.html#custom"},{"doc":"apollo/filter","title":"custom_string","content":"pub fn custom_string(v: Value, validator: fn(String) -&gt;\n    Result(Nil, String)) -&gt; Value\n Shorthand to create a custom filter for only string types\n # Example\n     pub fn is_gleam(v: Value) {\n         custom_string(\n           v,\n           fn(t: String) {\n             to_err(t == &quot;Gleam&quot;, &quot;Uh oh, expecting the word Gleam&quot;)\n           }\n         )\n      }\nSynonyms:\napollo/filter.custom_string\napollo/filter custom_string","url":"apollo/filter.html#custom_string"},{"doc":"apollo/filter","title":"length","content":"pub fn length(v: Value, length l: Int) -&gt; Value\n\nSynonyms:\napollo/filter.length\napollo/filter length","url":"apollo/filter.html#length"},{"doc":"apollo/filter","title":"max","content":"pub fn max(v: Value, length l: Int) -&gt; Value\n\nSynonyms:\napollo/filter.max\napollo/filter max","url":"apollo/filter.html#max"},{"doc":"apollo/filter","title":"min","content":"pub fn min(v: Value, length l: Int) -&gt; Value\n\nSynonyms:\napollo/filter.min\napollo/filter min","url":"apollo/filter.html#min"},{"doc":"apollo/filter","title":"regex","content":"pub fn regex(v: Value, regex re: Regex) -&gt; Value\n\nSynonyms:\napollo/filter.regex\napollo/filter regex","url":"apollo/filter.html#regex"},{"doc":"apollo/filter","title":"apollo/filter","content":" Create and use filters to narrow down on types","url":"apollo/filter.html"}]);